@@ -150,7 +150,6 @@ bool rate_adagrad = false;
 bool rda_mode = false;
 bool loss_rank = false; // loss by rank
 bool softmax_margin = false;
-bool project_weight = false;
 bool merge_oracle_mode = false;
 bool line_search_mode = false;    // perform line-search
 bool mert_search_mode = false;    // perform MERT search
@@ -1800,7 +1799,6 @@ void options(int argc, char** argv)
 
     ("loss-rank",           po::bool_switch(&loss_rank),          "rank loss")
     ("softmax-margin",      po::bool_switch(&softmax_margin),     "softmax margin")
-    ("project-weight",      po::bool_switch(&project_weight),     "project L2 weight")
     ("merge-oracle",        po::bool_switch(&merge_oracle_mode),  "merge oracle kbests")
     ("line-search",         po::bool_switch(&line_search_mode),   "perform line search")
     ("mert-search",         po::bool_switch(&mert_search_mode),   "perform mert search")
